.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.graph.entities.bibliographic.responsible\_agent module
---------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.responsible_agent
   :members:
   :undoc-members:
   :show-inheritance:
